\name{ci.cmpr}
\alias{ci.cmpr}
\alias{ci.prob}
\title{Compute state probabilities and simulated confidence intervals in
  a competing risk model from models for the cause specific rates. 
}
\description{
  Beyond state probabilities starting at time 0, the
  function can compute cumulative sums of the probabilities (for stacked
  plots of state probabilities), as well as estimates and confidence
  intervals for sojourn probabilities.
}
\usage{
ci.cmpr( mods,
           nd,
            N,
          int = mean(diff(nd[,1])),
         what = "prob",
         perm = 1:(length(mods)+1),
        alpha = 0.05 )
}
\arguments{
  \item{mods}{
   A named list of model objects representing fitted models for the
   rates of each of the competing events. The names will be used for the
   states.
}
  \item{nd}{
   A data frame used for prediction of the rates. Must contain columns
   for all the variables in the model. It is assumed that \code{nd} has
   one row for each interval after starting time, corresponding to the
   midpoint of the interval, adn that these are equidistant.
}
  \item{N}{
   Number of simulations to base the confidence intervals on.
}
  \item{int}{Scalar.
   The length of the intervals in which \code{nd} produce rate predictions.
}
  \item{what}{Character of length up to 4, requesting whether state
    probabilities (\code{prob}), stacked probabilities (\code{stack}),
    sojourn times \code{sojourn} times or the entire sampled object
    (\code{sample}) be returned. Only the two first characters of each
    entry is used, case insensitive. 
}
  \item{perm}{If \code{stack} is in the rgument \code{what}, \code{perm}
    will determine in what order state probabilities (at each tie point)
    are cumulated. The default order is \code{Surv} (no event) followed
    by the competing events in the order given in the object
    \code{mods}. Ignored if '\code{perm}' is not in the argument \code{what}.
}
  \item{alpha}{1 minus the confidence level.
}

}
\details{The state probabilities are quite easily computed in a
  competing risks model, but much less so with the standard errors. This
  function therefor simulates these by simulating parameters in the
  models for the transitions using the estimated parameters as means and
  the hessian as the variance-covariance in a multivariate normal. These
  are then used to predict rates at a set of equidistant times, that
  then are used to compute (simulated) state probabilities, sums of
  these (for stacked plots) and sojurn times. The simulated samples are
  then use as basis for deriving confidence intervals (as well mean and
  medians) for the quantities.
}
\value{
    A list with \code{length(what)} elements, each is an array
    classified by statistic (\code{model}, \code{mean}, \code{median},
    \code{lo}, \code{hi}), time interval (endpoints), and state.

    The first dimension of each array indicates what the corresponding
    slice contains:

    \code{model}: predictions from the models for the transitions

    \code{mean}: the mean of the simulated values

    \code{50\%}: the median of the simulated values
    \code{2.5\%}: quantile of the simulated values
    \code{97.5\%}: quantile of the simulated values
}
\author{
  Bendix Carstensen,
  \url{http://BendixCarstensen.com}
}
\seealso{
\code{\link{help}}, ~~~
}
\examples{
##---- Should be DIRECTLY executable !! ----
##-- ==>  Define data, use random,
##--	or do  help(data=index)  for the standard data sets.

## The function is currently defined as
function (mods, nd, N, int = mean(diff(nd[, 1])), what = "prob", 
    perm = 1:(length(mods) + 1)) 
{
    smpr <- mksm(mods = mods, nd = nd, N = N, int = int)
    wh <- tolower(substr(what, 1, 2))
    rs <- list(probs = if ("pr" \%in\% wh) prci(smpr), stack = if ("st" \%in\% 
        wh) prst(smpr, perm = perm), sojourn = if ("so" \%in\% 
        wh | "sj" \%in\% wh) prsj(smpr), sample = if ("sa" \%in\% 
        wh | "sm" \%in\% wh) smpr)
    rs <- rs[which(!sapply(rs, is.null))]
    if (length(rs) == 1) 
        rs <- rs[[1]]
    rs
  }
}
% Add one or more standard keywords, see file 'KEYWORDS' in the
% R documentation directory.
\keyword{ ~kwd1 }% use one of  RShowDoc("KEYWORDS")
\keyword{ ~kwd2 }% __ONLY ONE__ keyword per line
